@@ -1,11 +1,41 @@
-/* KNL v1.0.1 Program to configure the initial kernel settings.
- * Copyright (C) 1998, Riley H. Williams <rhw@bigfoot.com>
+/* KNL v1.0.4 Program to configure the initial kernel settings.
+ * Copyright (C) 1998-2003, Riley Williams <Riley@Williams.Name>
  *
  * This program and the associated documentation are distributed under
- * the GNU General Public Licence (GPL).
+ * the GNU General Public Licence (GPL), version 2 only.
+ *
+ **************************************************************************
+ *
+ * CHANGELOG:
+ * ~~~~~~~~~
+ *
+ *   1.0.4	Riley Williams <Riley@Williams.Name>
+ *
+ *	* Added ELKS port and compilation (as elks2).
+ *
+ *   1.0.3.1	Tomas Guemes <Tomas@Echeide.Net>
+ *
+ *	* Generalised Makefile.
+ *
+ *   1.0.3	Riley Williams <Riley@Williams.Name>
+ *
+ *	* Bugfix - Video selection display routine did not handle
+ *	  negative values correctly.
+ *
+ *   1.0.2	Riley Williams <Riley@Williams.Name>
+ *
+ *	* Implemented tweaks suggested by Debian Linux maintainers.
+ *
+ *   1.0.1	Riley Williams <Riley@Williams.Name>
+ *
+ *	* Added option to allow program to run silently.
+ *
+ *   1.0.0	Riley Williams <Riley@Williams.Name>
+ *
+ *	* Initial public release.
  */
 
-#define VERSION "1.0.1"
+#define VERSION "1.0.4"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -13,6 +43,10 @@
 #include <ctype.h>
 #include <string.h>
 
+#ifdef __BCC__
+#define signed
+#endif
+
 /* Standard types used in this program
  */
 
@@ -35,9 +69,10 @@ void help(void)
 {
     fprintf( stderr,
 	     "knl " VERSION " Program to configure initial kernel settings\n"
-	     "Copyright (C) 1998, Riley H. Williams <rhw@bigfoot.com>\n\n"
+	     "Copyright (C) 1998-2003, Riley Williams <Riley@Williams.Name>\n\n"
 	     "This program and the associated documentation are distributed under the\n"
-	     "GNU General Public Licence (GPL). See the file COPYING for details.\n\n"
+	     "GNU General Public Licence (GPL), version 2 only. See the file COPYING\n"
+	     "for details.\n\n"
 	     "Syntax:  knl [--kernel=]image [-f=flaglist] [--flags=flaglist]\n"
 	     "             [--noram] [-p] [--prompt] [--ram=offset] [-r=device]\n"
 	     "             [--root=device] [-s=device] [--swap=device] [--help]\n"
@@ -629,11 +664,12 @@ char *SetFlags( WORD Flags )
 
 char *SetVideo( WORD Value )
 {
-    char *Result;
+    char Buffer[32], *Result;
 
-    Value--;
-    if (Value > 65498)
-	switch (65535 - (long) Value) {
+    if (Value > 65499) {
+	Value -= 32768;
+	Value = 32768 - Value;
+	switch (Value) {
 	    case 0:
 		Result = "0 (Normally 80x25)";
 		break;
@@ -647,13 +683,13 @@ char *SetVideo( WORD Value )
 		Result = "Ask";
 		break;
 	    default:
-		Result = (char *) malloc(24);
-		sprintf( Result, "Undefined (-%lu)", 65535 - (long) Value );
+		Result = Buffer;
+		sprintf( Result, "Undefined (-%u)", Value );
 		break;
 	}
-    else {
-	Result = (char *) malloc(8);
-	sprintf( Result, "%u", ++Value );
+    } else {
+	Result = Buffer;
+	sprintf( Result, "%u", Value );
     }
     return Result;
 }
